@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2019 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -28,13 +28,9 @@
 
 
 import io
-import logging
 
 from openpyxl import Workbook
 
-log = logging.getLogger(__name__)
-log.addHandler(logging.NullHandler())
-
 
 def excel_to_bytes(wb: Workbook) -> bytes:
     """
